Documentation
¶
Index ¶
Constants ¶
const Size = highwayhash.Size128
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Hash ¶ added in v0.2.0
Hash is a 128bit unique identifier for a chunk or object.
func Cast ¶ added in v0.2.0
Cast converts a byte slice to a fixed length hash. In a future version of Go this utility will no longer be necessary.
func (*Hash) MarshalJSON ¶ added in v0.2.0
func (*Hash) UnmarshalJSON ¶ added in v0.2.0
Click to show internal directories.
Click to hide internal directories.